@@ -1,7 +1,8 @@
+##
+## use demo(... , ask=F) to run the demo all at once
+##
 ## Load package
 require("SPOT")
-## (for calls from demo():) disable interactive confirmation of plots
-old.demo.ask <- options("demo.ask" = FALSE)
 ## get path of test project
 testPath<-.find.package("SPOT")
 testPath<-file.path(testPath,"demo14LmOptimSann")
@@ -10,5 +11,3 @@ testPath
 ## run example
 testFile<-file.path(testPath,"demo14LmOptimSann.conf")
 spotConfig=spot(testFile)
-## (for calls from demo():) reset confirmation of plots to previous setting
-options("demo.ask" = old.demo.ask)
